@@ -2,38 +2,27 @@ package WWW::Shorten::RevCanonical;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use base qw( WWW::Shorten::generic Exporter );
 our @EXPORT = qw( makeashorterlink makealongerlink );
 
 use Carp;
 use LWP::UserAgent;
-use XML::LibXML;
 
 sub _ua {
     my $ua = LWP::UserAgent->new;
     $ua->env_proxy;
-    $ua->parse_head(0);
     $ua;
 }
 
 sub makeashorterlink {
     my $url = shift or croak "URL is required";
 
-    my $content = _ua->get($url)->content;
-
-    my $parser = XML::LibXML->new();
-    $parser->recover(1);
-    $parser->recover_silently(1);
-    $parser->keep_blanks(0);
-    $parser->expand_entities(1);
-    $parser->no_network(1);
-
-    my $doc = $parser->parse_html_string($content);
-    my @links = $doc->findnodes("//link[contains(concat(' ', \@rev, ' '), ' canonical ')]");
+    my $res  = _ua->get($url);
+    my @links = grep /^<.*?>;.*\brev="canonical"/, $res->header('Link');
     if (@links) {
-        return $links[0]->getAttribute('href');
+        return ($links[0] =~ /^<(.*?)>/)[0];
     }
 
     return;
@@ -88,7 +77,7 @@ WWW::Shorten::RevCanonical is a WWW::Shorten plugin to extract
 rev="canonical" link from HTML web pages. Unlike other URL shortening
 services, the ability to make a short URL from rev="canonical" depends
 on whether the target site implements the tag, so the call to
-C<makeashorterlink> could fail, and in that case you'll get L<undef>
+C<makeashorterlink> could fail, and in that case you'll get I<undef>
 result. You might want to fallback to other shorten services like
 I<TinyURL>.
 
